@@ -1,8 +1,8 @@
 rescale.indscal <-
-  function(x, mode="B", newscale=1, ...){
+  function(x, mode = "B", newscale = 1, ...){
     # Rescales Weights of fit INDSCAL model
     # Nathaniel E. Helwig (helwig@umn.edu)
-    # last updated: August 19, 2015    
+    # last updated: May 25, 2018
     
     # check mode
     mode <- mode[1]
@@ -11,11 +11,13 @@ rescale.indscal <-
     # check newscale
     nfac <- ncol(x$B)
     if(length(newscale)!=nfac) newscale <- rep(newscale[1],nfac)
+    if(any(newscale <= 0)) stop("Input 'newscale' must contain positive values.")
     
     # rescale factors
     if(mode=="B"){
       
       Bscale <- sqrt(colMeans(x$B^2))
+      if(any(Bscale == 0)) Bscale[Bscale == 0] <- 1
       svec <- newscale/Bscale
       if(nfac==1L) { Smat <- matrix(svec) } else { Smat <- diag(svec) }
       x$B <- x$B %*% Smat
@@ -26,6 +28,7 @@ rescale.indscal <-
     } else {
       
       Cscale <- sqrt(colMeans(x$C^2))
+      if(any(Cscale == 0)) Cscale[Cscale == 0] <- 1
       svec <- newscale/Cscale
       if(nfac==1L) { Smat <- matrix(svec) } else { Smat <- diag(svec) }
       x$C <- x$C %*% Smat
